﻿# © kbd-intl@narod.ru, 2011–2012
# I, the copyright holder of this work, hereby place it into the public domain.

from utils.keyboardModule import *

# “English (International)” keyboard layout.
keyboardName = 'en-intl'

# Outer list represents rows; inner lists represent keys within a row.
keyboard = [
    
    # ---- Number row ---------------------------------------------------------
    [   
        Key(Letter('~'), 
            Letter('`'), 
            Letter('\u0303', 'dead', 6, 3, isDiacritic = True), 
            Letter('\u0300', 'dead', 6, isDiacritic = True), 
            'grave'),

        Key(Letter('!'), 
            Letter('1'), 
            Letter('¡', 'winstd'), 
            Letter('§', 'winstd'), 
            'section'),
        
        Key(Letter('@'), 
            Letter('2'), 
            Letter('°', 'winstd'), 
            Letter('\u0304', 'dead', isDiacritic = True), 
            'macron'),
            
        Key(Letter('#'), 
            Letter('3'), 
            Letter('″', 'unicode'), 
            Letter('′', 'unicode'), 
            'minute'),
            
        Key(Letter('$'), 
            Letter('4'), 
            None, 
            Letter('€', 'winstd'), 
            'euro'),
            
        Key(Letter('%'), 
            Letter('5'), 
            Letter('→', 'unicode'), 
            Letter('‰', 'winstd'), 
            'permille'),

        Key(Letter('^'), 
            Letter('6'), 
            Letter('\u0311', 'dead', isDiacritic = True), 
            Letter('\u0302', 'dead', isDiacritic = True), 
            'circumflex'),

        Key(Letter('&'), 
            Letter('7'), 
            Letter('≈', 'unicode'), 
            Letter('©', 'winstd'), 
            'copyright'),

        Key(Letter('*'), 
            Letter('8'), 
            Letter('∙', 'unicode'), 
            Letter('×', 'winstd'), 
            'multiplication'),

        Key(Letter('('), 
            Letter('9'), 
            Letter('“', 'winstd', isQuote = True), 
            Letter('‘', 'winstd', isQuote = True), 
            'left-quote'),

        Key(Letter(')'), 
            Letter('0'), 
            Letter('”', 'winstd', isQuote = True), 
            Letter('’', 'winstd', isQuote = True), 
            'right-quote'),

        Key(Letter('_'), 
            Letter('-'), 
            Letter('−', 'unicode'), 
            Letter('—', 'winstd'), 
            'dash'),

        Key(Letter('+'), 
            Letter('='), 
            Letter('≠', 'unicode'), 
            Letter('±', 'winstd'), 
            'plus-minus'),

        Key(None, None, None, None, width = 2.0, systemText = 'Backspace')
    ],
    
    # ---- Upper row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Tab'),

        Key(Letter('Q'), 
            Letter('ǃ', 'var1'), 
            Letter('\u031b', 'dead', 3, 4, isDiacritic = True), 
            Letter('\u0328', 'dead', 4, isDiacritic = True), 
            'ogonek'),

        Key(Letter('W'), 
            None, 
            None,
            Letter('ʻ', 'unicode', 3, isQuote = True),
            'okina',
            middleDownLetter = Letter('ƿ', 'var2')),
        
        Key(Letter('E', 'std', -3), 
            Letter('Ɛ', 'var1', -3),
            None,
            Letter('Ə', 'unicode', 3),
            'turned-e',
            middleDownLetter = Letter('ɜ', 'var2', -1)),

        Key(Letter('R', 'std', -3), 
            Letter('ɾ', 'var1', -3),
            Letter('\u25A0', 'var3', 3),
            Letter('®', 'winstd', 3),
            'registered',
            middleDownLetter = Letter('ʀ', 'var2', -2)),

        Key(Letter('T', 'std', -2), 
            Letter('Ʈ', 'var1', -2),
            None,
            Letter('Þ', 'winstd', 3),
            'thorn',
            middleDownLetter = Letter('θ', 'var2')),

        Key(Letter('Y', 'std', -1), 
            Letter('Ɣ', 'var1', -1),
            Letter('¥', 'winstd', 2),
            Letter('ʼ', 'unicode', 2, isQuote = True),
            'glottal-stop',
            middleDownLetter = Letter('ʏ', 'var2')),

        Key(Letter('U', 'std', -2), 
            Letter('Ʊ', 'var1', -2),
            Letter('\u030a', 'dead', isDiacritic = True, diacriticCorr = 3), 
            Letter('\u0306', 'dead', isDiacritic = True, diacriticCorr = 3), 
            'breve',
            middleDownLetter = Letter('\u032f', 'var2', isDiacritic = True)),

        Key(Letter('I'), 
            Letter('ɪ', 'var1'),
            None, 
            Letter('İı', 'unicode'),
            'turkish-i'),

        Key(Letter('O', 'std', -3), 
            Letter('Ɵ', 'var1', -3),
            None, 
            Letter('Œ', 'winstd', 4),
            'oe',
            middleDownLetter = Letter('ɒ', 'var2', -2)),

        Key(Letter('P'), 
            Letter('ʘ', 'var1'),
            Letter('…', 'winstd', isQuote = True), 
            Letter('¶', 'winstd'),
            'paragraph'),

        Key(Letter('{'), 
            Letter('['),
            Letter('‹', 'winstd'),
            Letter('«', 'winstd'),
            'left-angle-quote'),

        Key(Letter('}'), 
            Letter(']'),
            Letter('›', 'winstd'),
            Letter('»', 'winstd'),
            'right-angle-quote'),

        Key(Letter('|'), 
            Letter('\\'),
            Letter('÷', 'winstd'),
            Letter('–', 'winstd'),
            width = 1.5)
    ],
    
    # ---- Middle row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.75, systemText = 'Caps Lock'),
        
        Key(Letter('A', 'std', -3), 
            Letter('ɑ', 'var1', -3),
            None,
            Letter('Æ', 'winstd', 4),
            'ae',
            middleDownLetter = Letter('ɐ', 'var2', -2)),

        Key(Letter('S', 'std', -2), 
            Letter('ʃ', 'var1', -2),
            None,
            Letter('ß', 'winstd', 3),
            'sharp-s',
            middleDownLetter = Letter('ſ', 'var2', -1)),
        
        Key(Letter('D'), 
            Letter('ɖ', 'var1'),
            None, 
            Letter('ð', 'winstd'),
            'eth'),

        Key(Letter('F'), 
            Letter('ɟ', 'var1'),
            Letter('\u25A0', 'var2'),
            Letter('\u25A0', 'var1'),
            'african'),

        Key(Letter('G', 'std', -3), 
            Letter('Ƹ', 'var1', -3),
            Letter('ʕ', 'unicode', 1, fontName = 'Arial', fontSize = 21),
            Letter('ʿ', 'unicode', 1),
            'ayin',
            middleDownLetter = Letter('ɡ', 'var2')),

        Key(Letter('H', 'std', -2), 
            Letter('Ɂ', 'var1', -2),
            Letter('ʔ', 'unicode', 1, fontName = 'Arial', fontSize = 21),
            Letter('ʾ', 'unicode', 1),
            'hamza',
            middleDownLetter = Letter('ʁ', 'var2', 1)),

        Key(Letter('J', 'std', -2), 
            Letter('Ɩ', 'var1', -2, fontName = 'Lucida Sans Unicode', 
                fontSize = 21),
            None,
            Letter('\u0321', 'dead', 3, 1, isDiacritic = True, 
                diacriticCorr = 3),
            'hook',
            middleDownLetter = Letter('ɥ', 'var2', -1)),

        Key(Letter('K'), 
            Letter('ǂ', 'var1'),
            Letter('ĸ', 'unicode'),
            Letter('™', 'winstd'),
            'trademark'),

        Key(Letter('L'), 
            None,
            Letter('£', 'winstd'),
            Letter('\u0331', 'dead', 0, -1, isDiacritic = True), 
            'macron-below'),

        Key(Letter(':', isQuote = True),
            Letter(';', isQuote = True),
            Letter('\u030F', 'dead', isDiacritic = True), 
            Letter('\u0308', 'dead', isDiacritic = True),
            'diaeresis',
            middleDownLetter = Letter('ː', 'var1', -1,
                fontName = 'Tahoma', fontSize = 20, isFontBold = True)),

        Key(Letter('"'), 
            Letter("'"),
            Letter('\u030b', 'dead', 1, isDiacritic = True),
            Letter('\u0301', 'dead', 6, isDiacritic = True),
            'acute',
            middleDownLetter = Letter('ˈ', 'var1', -1, -1,
                fontName = 'Arial Unicode MS', fontSize = 21, 
                isFontBold = True)),

        Key(None, None, None, None, width = 2.25, systemText = 'Enter')
    ], 
    
    # ---- Lower row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.25, systemText = 'Shift'),
        
        Key(Letter('|'), 
            Letter('\\'),
            Letter('÷', 'winstd'),
            Letter('–', 'winstd'),
            'en-dash'),

        Key(Letter('Z', 'std', -1), 
            Letter('ǀ', 'var1', -1),
            Letter('„', 'winstd', 3, isQuote = True),
            Letter('‚', 'winstd', 3, isQuote = True),
            'lower-quote',
            middleDownLetter = Letter('ȝ', 'var2')),

        Key(Letter('X'), 
            Letter('ǁ', 'var1'),
            Letter('ª', 'dead'),
            Letter('·', 'winstd'),
            'interpunct'),

        Key(Letter('C'), 
            Letter('Ɔ', 'var1'),
            Letter('¢', 'winstd'),
            # This symbol looks better in the font used for quotation marks.
            Letter('\u0327', 'dead', isDiacritic = True, isQuote = True),
            'cedilla'),

        Key(Letter('V'), 
            Letter('Ʌ', 'var1'),
            None,
            Letter('\u030c', 'dead', isDiacritic = True),
            'caron'),

        Key(Letter('B', 'std', -1), 
            Letter('Ǝ', 'var1', -1),
            None, 
            Letter('Ʒ', 'unicode', 2),
            'dz',
            middleDownLetter = Letter('ɹ', 'var2')),

        Key(Letter('N'), 
            Letter('ɴ', 'var1'),
            None,
            Letter('Ŋ', 'unicode'),
            'eng'),

        Key(Letter('M'), 
            Letter('Ƞ', 'var1'),
            Letter('Ω', 'unicode'),
            Letter('μ', 'unicode'),
            'mu'),

        Key(Letter('<'), 
            Letter(',', isQuote = True), 
            Letter('\u0309', 'dead', -5, isDiacritic = True),
            Letter('\u0326', 'dead', isDiacritic = True),
            'comma',
            middleDownLetter = Letter('ˌ', 'var1', -1,
                fontName = 'Arial Unicode MS', fontSize = 21, 
                isFontBold = True)),

        Key(Letter('>'), 
            Letter('.', isQuote = True), 
            Letter('\u0307', 'dead', isDiacritic = True),
            Letter('\u0323', 'dead', -5, isDiacritic = True),
            'dot'),

        Key(Letter('?'), 
            Letter('/'), 
            Letter('¿', 'winstd'),
            Letter('\u0338', 'dead', 1, isDiacritic = True),
            'solidus'),

        Key(None, None, None, None, width = 2.75, systemText = 'Shift')
    ],
    
    # ---- System row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt'),
        Key(None, None, None, None, width = 5.75, keyName = 'space',
            middleUpLetter = Letter('↑ non-breaking space ↑', 'winstd')),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt Gr'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Menu'),
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl')
    ]
]
        
createKeyboardFiles(keyboard, keyboardName)
