﻿# © kbd-intl@narod.ru, 2011–2012
# I, the copyright holder of this work, hereby place it into the public domain.

from utils.keyboardModule import *

# Ilya Birman’s typographic layout.
keyboardName = 'en-typography'

# Outer list represents rows; inner lists represent keys within a row.
keyboard = [
    
    # ---- Number row ---------------------------------------------------------
    [   
        Key(Letter('~'), 
            Letter('`'), 
            Letter('\u0300', 'dead', 6, isDiacritic = True), 
            None),

        Key(Letter('!'), 
            Letter('1'), 
            Letter('¡', 'winstd'),
            Letter('¹', 'winstd')),
        
        Key(Letter('@'), 
            Letter('2'), 
            Letter('½', 'winstd'),
            Letter('²', 'winstd')),
            
        Key(Letter('#'), 
            Letter('3'), 
            Letter('⅓', 'unicode'),
            Letter('³', 'winstd')),
            
        Key(Letter('$'), 
            Letter('4'), 
            Letter('¼', 'winstd'),
            Letter('$', 'winstd')),
            
        Key(Letter('%'), 
            Letter('5'), 
            None, 
            Letter('‰', 'winstd')),

        Key(Letter('^'), 
            Letter('6'), 
            Letter('\u0302', 'dead', isDiacritic = True), 
            Letter('↑', 'unicode')),

        Key(Letter('&'), 
            Letter('7'), 
            Letter('¿', 'winstd'),
            None),

        Key(Letter('*'), 
            Letter('8'), 
            None, 
            Letter('∞', 'unicode')),

        Key(Letter('('), 
            Letter('9'), 
            None, 
            Letter('←', 'unicode')),

        Key(Letter(')'), 
            Letter('0'), 
            None, 
            Letter('→', 'unicode')),

        Key(Letter('_'), 
            Letter('-'), 
            Letter('–', 'winstd'),
            Letter('—', 'winstd')), 

        Key(Letter('+'), 
            Letter('='), 
            Letter('±', 'winstd'),
            Letter('≠', 'unicode')), 

        Key(None, None, None, None, width = 2.0, systemText = 'Backspace')
    ],
    
    # ---- Upper row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Tab'),

        Key(Letter('Q'), 
            None, 
            Letter('\u0306', 'dead', isDiacritic = True),
            None), 

        Key(Letter('W'), 
            None, 
            None, 
            None),
        
        Key(Letter('E'), 
            None, 
            None, 
            Letter('€', 'winstd')),

        Key(Letter('R'), 
            None, 
            Letter('\u030a', 'dead', isDiacritic = True),
            Letter('®', 'winstd')),

        Key(Letter('T'), 
            None, 
            None, 
            Letter('™', 'winstd')),

        Key(Letter('Y'), 
            None, 
            None, 
            Letter('Ѣ', 'unicode')),

        Key(Letter('U'), 
            None, 
            None, 
            Letter('Ѵ', 'unicode')),

        Key(Letter('I'), 
            None, 
            None, 
            Letter('І', 'unicode')),

        Key(Letter('O'), 
            None, 
            None, 
            Letter('Ѳ', 'unicode')),

        Key(Letter('P'), 
            None, 
            Letter('″', 'unicode'),
            Letter('′', 'unicode')),

        Key(Letter('{'), 
            Letter('['), 
            Letter('{', 'winstd'),
            Letter('[', 'winstd')),

        Key(Letter('}'), 
            Letter(']'), 
            Letter('}', 'winstd'),
            Letter(']', 'winstd')),

        Key(Letter('|'), 
            Letter('\\'), 
            None, 
            None, 
            width = 1.5)
    ],
    
    # ---- Middle row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.75, systemText = 'Caps Lock'),
        
        Key(Letter('A'), 
            None, 
            Letter('⌘', 'unicode', fontName = "Arial Unicode MS", 
                fontSize = 20, isFontBold = True),
            Letter('≈', 'unicode')),

        Key(Letter('S'), 
            None, 
            None, 
            Letter('§', 'winstd')),
        
        Key(Letter('D'), 
            None, 
            Letter('⌀', 'unicode'),
            Letter('°', 'winstd')),

        Key(Letter('F'), 
            None, 
            None, 
            Letter('£', 'winstd')),

        Key(Letter('G'), 
            None, 
            None, 
            None),

        Key(Letter('H'), 
            None, 
            None, 
            None),

        Key(Letter('J'), 
            None, 
            None, 
            Letter('„', 'winstd', isQuote = True)),

        Key(Letter('K'), 
            None, 
            Letter('‘', 'winstd', isQuote = True),
            Letter('“', 'winstd', isQuote = True)),

        Key(Letter('L'), 
            None, 
            Letter('’', 'winstd', isQuote = True),
            Letter('”', 'winstd', isQuote = True)),

        Key(Letter(':', isQuote = True), 
            Letter(';', isQuote = True), 
            Letter('\u0308', 'dead', isDiacritic = True),
            Letter('‘', 'winstd', isQuote = True)),

        Key(Letter('"'), 
            Letter("'"), 
            None, 
            Letter('’', 'winstd', isQuote = True)),

        Key(None, None, None, None, width = 2.25, systemText = 'Enter')
    ], 
    
    # ---- Lower row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 2.25, systemText = 'Shift'),
        
        Key(Letter('Z'), 
            None, 
            # This symbol looks better in the font used for quotation marks.
            Letter('\u0327', 'dead', isDiacritic = True, isQuote = True),
            None),

        Key(Letter('X'), 
            None, 
            Letter('·', 'winstd'),
            Letter('×', 'winstd')),

        Key(Letter('C'), 
            None, 
            Letter('¢', 'winstd'),
            Letter('©', 'winstd')),

        Key(Letter('V'), 
            None, 
            Letter('\u030c', 'dead', isDiacritic = True),
            Letter('↓', 'unicode')),

        Key(Letter('B'), 
            None, 
            None, 
            Letter('ß', 'winstd')),

        Key(Letter('N'), 
            None, 
            Letter('\u0303', 'dead', 6, 3, isDiacritic = True), 
            None),

        Key(Letter('M'), 
            None, 
            Letter('•', 'winstd'),
            Letter('−', 'unicode')),

        Key(Letter('<'), 
            Letter(',', isQuote = True), 
            Letter('„', 'winstd', isQuote = True), 
            Letter('«', 'winstd')), 

        Key(Letter('>'), 
            Letter('.', isQuote = True), 
            Letter('“', 'winstd', isQuote = True), 
            Letter('»', 'winstd')), 

        Key(Letter('?'), 
            Letter('/'), 
            Letter('\u0301', 'dead', 6, isDiacritic = True), 
            Letter('…', 'winstd', isQuote = True)),

        Key(None, None, None, None, width = 2.75, systemText = 'Shift')
    ],
    
    # ---- System row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt'),
        Key(None, None, None, None, width = 5.75,
            middleDownLetter = Letter('non-breaking space', 'winstd')),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt Gr'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Menu'),
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl')
    ]
]
        
createKeyboardFiles(keyboard, keyboardName)
