﻿# © Ян Грудо, 2009—2011
#
# I, the copyright holder of this work, hereby place it into the public domain.

from utils.keyboardModule import *

# “Russian (International)” keyboard layout.
keyboardName = 'ru-intl'

# Outer list represents rows; inner lists represent keys within a row.
keyboard = [
    
    # ---- Number row ---------------------------------------------------------
    [   
        Key(Letter('Ё'), 
            None, 
            Letter('\u0300', 'unicode', 6, isDiacritic = True), 
            Letter('\u0301', 'unicode', 6, isDiacritic = True),
            'acute'),

        Key(Letter('!'), 
            Letter('1'), 
            Letter('\u030F', 'unicode', isDiacritic = True), 
            Letter('§', 'winstd'), 
            'section'),
        
        Key(Letter('"'), 
            Letter('2'), 
            Letter('°', 'winstd'), 
            Letter('\u0304', 'unicode', isDiacritic = True),
            'macron'),
            
        Key(Letter('№'), 
            Letter('3'), 
            Letter('″', 'unicode'),
            Letter('′', 'unicode'),
            'minute'),
            
        Key(Letter(';', isQuote = True), 
            Letter('4'), 
            Letter('₴', 'unicode'), 
            Letter('€', 'winstd'), 
            'euro'),
            
        Key(Letter('%'), 
            Letter('5'), 
            Letter('→', 'unicode'), 
            Letter('‰', 'winstd'), 
            'permille'),

        Key(Letter(':', isQuote = True), 
            Letter('6'), 
            Letter('\u0311', 'unicode', isDiacritic = True), 
            Letter('\u0302', 'unicode', isDiacritic = True), 
            'circumflex'),

        Key(Letter('?'), 
            Letter('7'), 
            Letter('≈', 'unicode'), 
            Letter('©', 'winstd'), 
            'copyright'),

        Key(Letter('*'), 
            Letter('8'), 
            Letter('∙', 'unicode'), 
            Letter('×', 'unicode'), 
            'multiplication'),

        Key(Letter('('), 
            Letter('9'), 
            Letter('„', 'winstd', isQuote = True), 
            Letter('«', 'winstd'), 
            'left-quote'),

        Key(Letter(')'), 
            Letter('0'), 
            Letter('“', 'winstd', isQuote = True), 
            Letter('»', 'winstd'), 
            'right-quote'),

        Key(Letter('_'), 
            Letter('-'), 
            Letter('−', 'unicode'), 
            Letter('—', 'winstd'), 
            'dash'),

        Key(Letter('+'), 
            Letter('='), 
            Letter('≠', 'unicode'), 
            Letter('±', 'winstd'), 
            'plus-minus'),

        Key(None, None, None, None, width = 2.0, systemText = 'Backspace')
    ],
    
    # ---- Upper row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Tab'),

        Key(Letter('Й'), 
            None, 
            None, 
            Letter('Ј', 'winstd'), 
            'j'),

        Key(Letter('Ц'), 
            None, 
            None, 
            Letter('\u25A0', 'var2'), 
            'slavonic'),
        
        Key(Letter('У'), 
            Letter('Ѫ', 'var2'), 
            Letter('Ӯ', 'var1'), 
            Letter('Ў', 'winstd'), 
            'short-u'),

        Key(Letter('К'), 
            Letter('Ҡ', 'var2'), 
            Letter('Қ', 'var1'), 
            Letter('Ќ', 'winstd'), 
            'kje'),

        Key(Letter('Е'), 
            Letter('Ѥ', 'var2'), 
            None, 
            Letter('Є', 'winstd'), 
            'je'),

        Key(Letter('Н'), 
            Letter('Ҥ', 'var2'), 
            Letter('Ң', 'var1'), 
            Letter('Њ', 'winstd'), 
            'nje'),

        Key(Letter('Г'), 
            Letter('Ҕ', 'var2'), 
            Letter('Ғ', 'var1'), 
            Letter('Ѓ', 'winstd'), 
            'gje'),

        Key(Letter('Ш'), 
            None, 
            Letter('\u030c', 'unicode', isDiacritic = True), 
            Letter('\u0306', 'dead', isDiacritic = True), 
            'breve'),

        Key(Letter('Щ'), 
            None, 
            Letter('\u0323', 'unicode', -5, isDiacritic = True),
            Letter('\u25A0', 'var1'), 
            'asian'),

        Key(Letter('З'), 
            None, 
            Letter('Ҙ', 'var1'), 
            Letter('Ѕ', 'winstd'), 
            'dze'),

        Key(Letter('Х'), 
            Letter('Ѯ', 'var2'), 
            Letter('Ҳ', 'var1'), 
            Letter('Һ', 'unicode'), 
            'ha'),

        Key(Letter('Ъ'), 
            None, 
            Letter('…', 'winstd', isQuote = True), 
            Letter('’', 'winstd', isQuote = True), 
            'apostrophe'),

        Key(Letter('/'), 
            Letter('\\'), 
            None, 
            Letter('Ґ', 'winstd'), 
            width = 1.5)
    ],
    
    # ---- Middle row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.75, systemText = 'Caps Lock'),
        
        Key(Letter('Ф'), 
            None, 
            None, 
            Letter('Ѳ', 'unicode'), 
            'fita'),

        Key(Letter('Ы'), 
            None, 
            None, 
            Letter('І', 'winstd'), 
            'i'),
        
        Key(Letter('В'), 
            Letter('Ѹ', 'var2'), 
            None,
            Letter('Ѵ', 'unicode'), 
            'izhitsa'),

        Key(Letter('А'), 
            None, 
            None, 
            Letter('Ӕ', 'unicode'), 
            'ae'),

        Key(Letter('П'), 
            Letter('Ѱ', 'var2'), 
            None, 
            Letter('ӏ', 'unicode'), 
            'palochka'),

        Key(Letter('Р'), 
            None, 
            None, 
            # Two lower pixel rows of the “a” letter have to be manually copied 
            # and then used to draw the slanted tail on the “м” key.
            Letter('ӊ', 'dead', 1, -3, isDiacritic = True)),

        Key(Letter('О'), 
            Letter('Ѻ', 'var2'), 
            None, 
            Letter('Ө', 'unicode'), 
            'oe'),

        Key(Letter('Л'), 
            None, 
            None, 
            Letter('Љ', 'winstd'), 
            'lje'),

        Key(Letter('Д'), 
            None, 
            None, 
            Letter('Ђ', 'winstd'), 
            'dje'),

        Key(Letter('Ж'), 
            None, 
            Letter('Җ', 'var1'), 
            Letter('Џ', 'winstd'), 
            'dzhe'),

        Key(Letter('Э'), 
            None, 
            None, 
            Letter('Ә', 'unicode'), 
            'turned-e'),

        Key(None, None, None, None, width = 2.25, systemText = 'Enter')
    ], 
    
    # ---- Lower row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.25, systemText = 'Shift'),
        
        Key(Letter('/'), 
            Letter('\\'), 
            None, 
            Letter('Ґ', 'winstd'), 
            'ge'),
        
        Key(Letter('Я'), 
            Letter('Ѩ', 'var2'), 
            None, 
            Letter('Ѧ', 'unicode'), 
            'little-yus'),

        Key(Letter('Ч'), 
            Letter('Ӌ', 'var2'), 
            Letter('Ҷ', 'var1'), 
            Letter('Ћ', 'winstd'), 
            'tshe'),

        Key(Letter('С'), 
            None,
            Letter('Ҫ', 'var1'), 
            # “a” letter has to be manually copied from some other key in order
            # to produce the final layout picture.
            Letter('ӈ', 'dead'), 
            'hook'),

        Key(Letter('М'), 
            Letter('Ѡ', 'var2'),
            None,
            # The final picture has to be assembled by hand using “a” letter
            # at the “р” key.
            Letter('ӊ', 'dead'), 
            'tail'),

        Key(Letter('И'), 
            None, 
            Letter('Ӣ', 'var1'), 
            Letter('Ї', 'winstd'), 
            'yi'),

        Key(Letter('Т'), 
            Letter('Ѿ', 'var2'),
            Letter('\u030a', 'unicode', isDiacritic = True), 
            Letter('\u0307', 'unicode', isDiacritic = True), 
            'dot'),

        Key(Letter('Ь'), 
            None, 
            None, 
            Letter('Ѣ', 'unicode'), 
            'yat'),

        Key(Letter('Б'), 
            None, 
            None, 
            Letter('\u25A0', 'var3'), 
            'abkhazian'),

        Key(Letter('Ю'), 
            Letter('Ѭ', 'var2'), 
            Letter('Ұ', 'var1'), 
            Letter('Ү', 'unicode'), 
            'straight-u'),

        Key(Letter(',', isQuote = True), 
            Letter('.', isQuote = True), 
            Letter('\u0312', 'unicode', isDiacritic = True), 
            Letter('\u0308', 'dead', isDiacritic = True), 
            'diaeresis'),

        Key(None, None, None, None, width = 2.75, systemText = 'Shift')
    ],
    
    # ---- System row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt'),
        Key(None, None, None, None, width = 5.75, keyName = 'space',
            middleUpLetter = Letter('↑ неразрывный пробел ↑', 'winstd')),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt Gr'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Menu'),
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl')
    ]
]
        
createKeyboardFiles(keyboard, keyboardName)
