﻿# © kbd-intl@narod.ru, 2011–2012
# I, the copyright holder of this work, hereby place it into the public domain.

from utils.keyboardModule import *

# Ilya Birman’s typographic layout.
keyboardName = 'ru-typography'

# Outer list represents rows; inner lists represent keys within a row.
keyboard = [
    
    # ---- Number row ---------------------------------------------------------
    [   
        Key(Letter('Ё'), 
            None, 
            Letter('\u0300', 'dead', 6, isDiacritic = True), 
            None),

        Key(Letter('!'), 
            Letter('1'), 
            Letter('¡', 'unicode'),
            Letter('¹', 'unicode')),
        
        Key(Letter('"'), 
            Letter('2'), 
            Letter('½', 'unicode'),
            Letter('²', 'unicode')),
            
        Key(Letter('№'), 
            Letter('3'), 
            Letter('⅓', 'unicode'),
            Letter('³', 'unicode')),
            
        Key(Letter(';', isQuote = True), 
            Letter('4'), 
            Letter('¼', 'unicode'),
            Letter('$', 'winstd')),
            
        Key(Letter('%'), 
            Letter('5'), 
            None, 
            Letter('‰', 'winstd')),

        Key(Letter(':', isQuote = True), 
            Letter('6'), 
            Letter('\u0302', 'dead', isDiacritic = True), 
            Letter('↑', 'unicode')),

        Key(Letter('?'), 
            Letter('7'), 
            Letter('¿', 'unicode'),
            None),

        Key(Letter('*'), 
            Letter('8'), 
            None, 
            Letter('∞', 'unicode')),

        Key(Letter('('), 
            Letter('9'), 
            None, 
            Letter('←', 'unicode')),

        Key(Letter(')'), 
            Letter('0'), 
            None, 
            Letter('→', 'unicode')),

        Key(Letter('_'), 
            Letter('-'), 
            Letter('–', 'winstd'),
            Letter('—', 'winstd')), 

        Key(Letter('+'), 
            Letter('='), 
            Letter('±', 'winstd'),
            Letter('≠', 'unicode')), 

        Key(None, None, None, None, width = 2.0, systemText = 'Backspace')
    ],
    
    # ---- Upper row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Tab'),

        Key(Letter('Й'), 
            None, 
            Letter('\u0306', 'dead', isDiacritic = True),
            None), 

        Key(Letter('Ц'), 
            None, 
            None, 
            None),
        
        Key(Letter('У'), 
            None, 
            None, 
            Letter('€', 'winstd')),

        Key(Letter('К'), 
            None, 
            Letter('\u030a', 'dead', isDiacritic = True),
            Letter('®', 'winstd')),

        Key(Letter('Е'), 
            None, 
            None, 
            Letter('™', 'winstd')),

        Key(Letter('Н'), 
            None, 
            None, 
            Letter('Ѣ', 'unicode')),

        Key(Letter('Г'), 
            None, 
            None, 
            Letter('Ѵ', 'unicode')),

        Key(Letter('Ш'), 
            None, 
            None, 
            Letter('І', 'winstd')),

        Key(Letter('Щ'), 
            None, 
            None, 
            Letter('Ѳ', 'unicode')),

        Key(Letter('З'), 
            None, 
            Letter('″', 'unicode'),
            Letter('′', 'unicode')),

        Key(Letter('Х'), 
            None, 
            Letter('{', 'winstd'),
            Letter('[', 'winstd')),

        Key(Letter('Ъ'), 
            None, 
            Letter('}', 'winstd'),
            Letter(']', 'winstd')),

        Key(Letter('/'), 
            Letter('\\'), 
            None, 
            None, 
            width = 1.5)
    ],
    
    # ---- Middle row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.75, systemText = 'Caps Lock'),
        
        Key(Letter('Ф'), 
            None, 
            Letter('⌘', 'unicode', fontName = "Arial Unicode MS", 
                fontSize = 20, isFontBold = True),
            Letter('≈', 'unicode')),

        Key(Letter('Ы'), 
            None, 
            None, 
            Letter('§', 'winstd')),
        
        Key(Letter('В'), 
            None, 
            Letter('⌀', 'unicode'),
            Letter('°', 'winstd')),

        Key(Letter('А'), 
            None, 
            None, 
            Letter('£', 'unicode')),

        Key(Letter('П'), 
            None, 
            None, 
            None),

        Key(Letter('Р'), 
            None, 
            None, 
            None),

        Key(Letter('О'), 
            None, 
            None, 
            Letter('„', 'winstd', isQuote = True)),

        Key(Letter('Л'), 
            None, 
            Letter('‘', 'winstd', isQuote = True),
            Letter('“', 'winstd', isQuote = True)),

        Key(Letter('Д'), 
            None, 
            Letter('’', 'winstd', isQuote = True),
            Letter('”', 'winstd', isQuote = True)),

        Key(Letter('Ж'), 
            None, 
            Letter('\u0308', 'dead', isDiacritic = True),
            Letter('‘', 'winstd', isQuote = True)),

        Key(Letter('Э'), 
            None, 
            None, 
            Letter('’', 'winstd', isQuote = True)),

        Key(None, None, None, None, width = 2.25, systemText = 'Enter')
    ], 
    
    # ---- Lower row ----------------------------------------------------------
    [
        Key(None, None, None, None, width = 2.25, systemText = 'Shift'),
        
        Key(Letter('Я'), 
            None, 
            # This symbol looks better in the font used for quotation marks.
            Letter('\u0327', 'dead', isDiacritic = True, isQuote = True),
            None),

        Key(Letter('Ч'), 
            None, 
            Letter('·', 'winstd'),
            Letter('×', 'unicode')),

        Key(Letter('С'), 
            None, 
            Letter('¢', 'unicode'),
            Letter('©', 'winstd')),

        Key(Letter('М'), 
            None, 
            Letter('\u030c', 'dead', isDiacritic = True),
            Letter('↓', 'unicode')),

        Key(Letter('И'), 
            None, 
            None, 
            Letter('ß', 'unicode')),

        Key(Letter('Т'), 
            None, 
            Letter('\u0303', 'dead', 6, 3, isDiacritic = True), 
            None),

        Key(Letter('Ь'), 
            None, 
            Letter('•', 'winstd'),
            Letter('−', 'unicode')),

        Key(Letter('Б'), 
            None, 
            Letter('„', 'winstd', isQuote = True), 
            Letter('«', 'winstd')), 

        Key(Letter('Ю'), 
            None, 
            Letter('“', 'winstd', isQuote = True), 
            Letter('»', 'winstd')), 

        Key(Letter(',', isQuote = True), 
            Letter('.', isQuote = True), 
            Letter('\u0301', 'dead', 6, isDiacritic = True), 
            Letter('…', 'winstd', isQuote = True)),

        Key(None, None, None, None, width = 2.75, systemText = 'Shift')
    ],
    
    # ---- System row ---------------------------------------------------------
    [
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt'),
        Key(None, None, None, None, width = 5.75,
            middleDownLetter = Letter('неразрывный пробел', 'winstd')),
        Key(None, None, None, None, width = 1.25, systemText = 'Alt Gr'),
        Key(None, None, None, None, width = 1.25, systemText = 'Win'),
        Key(None, None, None, None, width = 1.25, systemText = 'Menu'),
        Key(None, None, None, None, width = 1.5, systemText = 'Ctrl')
    ]
]
        
createKeyboardFiles(keyboard, keyboardName)
